@@ -2,18 +2,16 @@ package Catalyst::Action::Serialize::JSON::XS;
 
 use Moose;
 use namespace::autoclean;
+BEGIN {
+    $ENV{'PERL_JSON_BACKEND'} = 2; # Always use compiled JSON::XS
+}
 
 extends 'Catalyst::Action::Serialize::JSON';
 use JSON::XS ();
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 $VERSION = eval $VERSION;
 
-sub _build_encoder {
-   my $self = shift;
-   return JSON::XS->new->convert_blessed;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
